.. _install:



Install
-------

pip
^^^

Using **pip**, install lmlib in the command shell with command

.. code-block:: console

    pip install lmlib

To install in **developer mode**, type

.. code-block:: console

    pip install -e lmlib


conda
^^^^^

For **conda** users, the installation runs via the *pip installer* of conda.

1. Create a virtual environment (here: venv)

.. code-block:: console

    conda create -n venv

2. Install conda pip

.. code-block:: console

    conda install pip

3. Install lmlib using the path to your virtual environment and install the package with

.. code-block:: console

    /anaconda/envs/venv/bin/pip install lmlib
